==> haskell-storable-complex-0.2.3.0-241-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-Gf2xvn7kKzD3WzrOoReVPH
key:                  storable-complex-0.2.3.0-Gf2xvn7kKzD3WzrOoReVPH
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  4e41d0a2285b08ce2b841b7b43e1f0ae
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-Gf2xvn7kKzD3WzrOoReVPH
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-9SrFWHJupRo443OOwuTGTo

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-243-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-FzoWKq5zpQhCsPZaXmVnSf
key:                  storable-complex-0.2.3.0-FzoWKq5zpQhCsPZaXmVnSf
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  eb56826314cb9a7cabc3c72dadee1858
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-FzoWKq5zpQhCsPZaXmVnSf
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
